#
# spec file for package ghc-clash-vhdl
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name clash-vhdl
Name:           ghc-%{pkg_name}
Version:        0.7.2
Release:        8.1
Summary:        CAES Language for Synchronous Hardware - VHDL backend
License:        BSD-2-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-clash-lib-devel
BuildRequires:  ghc-clash-prelude-devel
BuildRequires:  ghc-fgl-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-lens-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-wl-pprint-text-devel

%description
CλaSH (pronounced ‘clash’) is a functional hardware description language that
borrows both its syntax and semantics from the functional programming language
Haskell. The CλaSH compiler transforms these high-level descriptions to
low-level synthesizable VHDL, Verilog, or SystemVerilog.

Features of CλaSH:

* Strongly typed, but with a very high degree of type inference, enabling both
safe and fast prototyping using concise descriptions.

* Interactive REPL: load your designs in an interpreter and easily test all
your component without needing to setup a test bench.

* Higher-order functions, with type inference, result in designs that are fully
parametric by default.

* Synchronous sequential circuit design based on streams of values, called
'Signal's, lead to natural descriptions of feedback loops.

* Support for multiple clock domains, with type safe clock domain crossing.

This package provides:

* VHDL Backend.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE
%dir %{_datadir}/%{pkg_name}-%{version}
%dir %{_datadir}/%{pkg_name}-%{version}/primitives
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Class.BitPack.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Driver.TestbenchGen.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Driver.TopWrapper.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.GHC.GHC2Core.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Prelude.BlockRam.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Prelude.BlockRam.File.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Prelude.RAM.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Prelude.ROM.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Prelude.ROM.File.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Prelude.Testbench.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Promoted.Nat.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Promoted.Nat.Unsafe.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Promoted.Symbol.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Signal.Bundle.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Signal.Explicit.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Signal.Internal.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Sized.Internal.BitVector.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Sized.Internal.Index.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Sized.Internal.Signed.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Sized.Internal.Unsigned.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Sized.RTree.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Sized.Vector.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.Transformations.json
%{_datadir}/%{pkg_name}-%{version}/primitives/CLaSH.XException.json
%{_datadir}/%{pkg_name}-%{version}/primitives/Control.Exception.Base.json
%{_datadir}/%{pkg_name}-%{version}/primitives/Debug.Trace.json
%{_datadir}/%{pkg_name}-%{version}/primitives/GHC.Base.json
%{_datadir}/%{pkg_name}-%{version}/primitives/GHC.Classes.json
%{_datadir}/%{pkg_name}-%{version}/primitives/GHC.CString.json
%{_datadir}/%{pkg_name}-%{version}/primitives/GHC.Err.json
%{_datadir}/%{pkg_name}-%{version}/primitives/GHC.IO.Exception.json
%{_datadir}/%{pkg_name}-%{version}/primitives/GHC.Int.json
%{_datadir}/%{pkg_name}-%{version}/primitives/GHC.Integer.Logarithms.json
%{_datadir}/%{pkg_name}-%{version}/primitives/GHC.Integer.Type.json
%{_datadir}/%{pkg_name}-%{version}/primitives/GHC.Prim.json
%{_datadir}/%{pkg_name}-%{version}/primitives/GHC.Real.json
%{_datadir}/%{pkg_name}-%{version}/primitives/GHC.Typelits.json
%{_datadir}/%{pkg_name}-%{version}/primitives/GHC.Types.json
%{_datadir}/%{pkg_name}-%{version}/primitives/GHC.Word.json
%{_datadir}/%{pkg_name}-%{version}/primitives/Unsafe.Coerce.json

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Wed May  3 2017 psimons@suse.com
- Update to version 0.7.2 with cabal2obs.
* Wed Apr 19 2017 psimons@suse.com
- Update to version 0.7.1 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 0.7 with cabal2obs.
* Fri Oct 21 2016 psimons@suse.com
- Update to version 0.6.16 revision 1 with cabal2obs.
* Wed Aug 17 2016 psimons@suse.com
- Update to version 0.6.16 revision 0 with cabal2obs.
* Fri Jul 22 2016 psimons@suse.com
- Update to version 0.6.15 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.6.13 revision 0 with cabal2obs.
